@@ -5,7 +5,7 @@
 #' Type: \tab Package\cr
 #' Version: \tab 0.1\cr
 #' Date: \tab 2012-10-13\cr
-#' License: \tab BSD\cr
+#' License: \tab MIT\cr
 #' LazyLoad: \tab yes\cr}
 #'
 #' This package provides an R interface to the recent eBird database.
@@ -17,4 +17,5 @@
 #' @author  Rafael Maia \email{rm72@@zips.uakron.edu}, Scott Chamberlain \email{myrmecocystus@@gmail.com}
 #' @keywords package
 #' @examples #see functions.
-NA
\ No newline at end of file
+
+NULL
\ No newline at end of file
